@@ -22,7 +22,7 @@ pub async fn balanceof(token_addr: String, owner_address: String) -> web3::Resul
     let token_contract = Contract::from_json(
         web3s.eth(),
         contract_addr,
-        include_bytes!("../common/erc20_abi.json"),
+        include_bytes!("../common/xrc20_abi.json"),
     )
     .unwrap();
 
