@@ -21,7 +21,7 @@ pub async fn token_name(token_addr: String) -> web3::Result<String> {
     let token_contract = Contract::from_json(
         web3s.eth(),
         contract_addr,
-        include_bytes!("../common/erc20_abi.json"),
+        include_bytes!("../common/xrc20_abi.json"),
     )
     .unwrap();
 
